==> apache-plc4x-0.5.0-source-release.zip: apache-plc4x-0.5.0/plc4j/drivers/opcua/src/main/java/org/apache/plc4x/java/opcua/protocol/model/OpcuaIdentifierType.java <==
/*
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 */
package org.apache.plc4x.java.opcua.protocol.model;

/**
 * @author Matthias Milan Stlrljic
 * Created by Matthias Milan Stlrljic on 10.05.2019
 */
public enum OpcuaIdentifierType {
    STRING_IDENTIFIER("s"),
    NUMBER_IDENTIFIER("i"),
    GUID_IDENTIFIER("g"),
    BINARY_IDENTIFIER("BINARY_IDENTIFIER");

    private String text;

    OpcuaIdentifierType(String text) {
        this.text = text;
    }

    public String getText() {
        return this.text;
    }

    public static OpcuaIdentifierType fromString(String text) {
        for (OpcuaIdentifierType type : OpcuaIdentifierType.values()) {
            if (type.text.equalsIgnoreCase(text)) {
                return type;
            }
        }
        throw new IllegalArgumentException("No constant with text " + text + " found");
    }
}

==> apache-plc4x-0.6.0-source-release.zip: apache-plc4x-0.6.0/plc4j/drivers/opcua/src/main/java/org/apache/plc4x/java/opcua/protocol/model/OpcuaIdentifierType.java <==
/*
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 */
package org.apache.plc4x.java.opcua.protocol.model;

/**
 * Created by Matthias Milan Strljic on 10.05.2019
 */
public enum OpcuaIdentifierType {
    STRING_IDENTIFIER("s"),
    NUMBER_IDENTIFIER("i"),
    GUID_IDENTIFIER("g"),
    BINARY_IDENTIFIER("BINARY_IDENTIFIER");

    private String text;

    OpcuaIdentifierType(String text) {
        this.text = text;
    }

    public static OpcuaIdentifierType fromString(String text) {
        for (OpcuaIdentifierType type : OpcuaIdentifierType.values()) {
            if (type.text.equalsIgnoreCase(text)) {
                return type;
            }
        }
        throw new IllegalArgumentException("No constant with text " + text + " found");
    }

    public String getText() {
        return this.text;
    }
}
